==> open-webui-0.6.32-1-any.pkg.tar.zst: opt/open-webui/.svelte-kit/output/server/entries/pages/(app)/workspace/prompts/_page.svelte.js <==
import { c as create_ssr_component, b as subscribe, l as getContext, g as escape, v as validate_component } from "../../../../../chunks/ssr.js";
import "../../../../../chunks/Toaster.svelte_svelte_type_style_lang.js";
import "file-saver";
import "../../../../../chunks/client.js";
import { W as WEBUI_NAME, u as user, c as config } from "../../../../../chunks/index.js";
import "dequal";
import "../../../../../chunks/create.js";
import "dompurify";
import "../../../../../chunks/index2.js";
import "marked";
/* empty css                                                                */
import { S as Spinner } from "../../../../../chunks/Spinner.js";
const Prompts = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $i18n, $$unsubscribe_i18n;
  let $WEBUI_NAME, $$unsubscribe_WEBUI_NAME;
  let $$unsubscribe_user;
  let $$unsubscribe_config;
  $$unsubscribe_WEBUI_NAME = subscribe(WEBUI_NAME, (value) => $WEBUI_NAME = value);
  $$unsubscribe_user = subscribe(user, (value) => value);
  $$unsubscribe_config = subscribe(config, (value) => value);
  const i18n = getContext("i18n");
  $$unsubscribe_i18n = subscribe(i18n, (value) => $i18n = value);
  let $$settled;
  let $$rendered;
  let previous_head = $$result.head;
  do {
    $$settled = true;
    $$result.head = previous_head;
    $$rendered = `${$$result.head += `<!-- HEAD_svelte-16rw8in_START -->${$$result.title = `<title> ${escape($i18n.t("Prompts"))} • ${escape($WEBUI_NAME)} </title>`, ""}<!-- HEAD_svelte-16rw8in_END -->`, ""} ${`<div class="w-full h-full flex justify-center items-center">${validate_component(Spinner, "Spinner").$$render($$result, { className: "size-5" }, {}, {})}</div>`}`;
  } while (!$$settled);
  $$unsubscribe_i18n();
  $$unsubscribe_WEBUI_NAME();
  $$unsubscribe_user();
  $$unsubscribe_config();
  return $$rendered;
});
const Page = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  return `${validate_component(Prompts, "Prompts").$$render($$result, {}, {}, {})}`;
});
export {
  Page as default
};
//# sourceMappingURL=_page.svelte.js.map

==> open-webui-0.6.34-1-any.pkg.tar.zst: opt/open-webui/.svelte-kit/output/server/entries/pages/(app)/workspace/prompts/_page.svelte.js <==
import { c as create_ssr_component, b as subscribe, l as getContext, g as escape, v as validate_component } from "../../../../../chunks/ssr.js";
import "../../../../../chunks/Toaster.svelte_svelte_type_style_lang.js";
import "file-saver";
import "../../../../../chunks/client.js";
import { u as user, W as WEBUI_NAME, c as config } from "../../../../../chunks/index.js";
import "../../../../../chunks/index2.js";
import "dequal";
import "../../../../../chunks/create.js";
import "dompurify";
import "marked";
/* empty css                                                                */
import { S as Spinner } from "../../../../../chunks/Spinner.js";
const Prompts = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $i18n, $$unsubscribe_i18n;
  let $$unsubscribe_user;
  let $WEBUI_NAME, $$unsubscribe_WEBUI_NAME;
  let $$unsubscribe_config;
  $$unsubscribe_user = subscribe(user, (value) => value);
  $$unsubscribe_WEBUI_NAME = subscribe(WEBUI_NAME, (value) => $WEBUI_NAME = value);
  $$unsubscribe_config = subscribe(config, (value) => value);
  const i18n = getContext("i18n");
  $$unsubscribe_i18n = subscribe(i18n, (value) => $i18n = value);
  let $$settled;
  let $$rendered;
  let previous_head = $$result.head;
  do {
    $$settled = true;
    $$result.head = previous_head;
    $$rendered = `${$$result.head += `<!-- HEAD_svelte-16rw8in_START -->${$$result.title = `<title> ${escape($i18n.t("Prompts"))} • ${escape($WEBUI_NAME)} </title>`, ""}<!-- HEAD_svelte-16rw8in_END -->`, ""} ${`<div class="w-full h-full flex justify-center items-center">${validate_component(Spinner, "Spinner").$$render($$result, { className: "size-5" }, {}, {})}</div>`}`;
  } while (!$$settled);
  $$unsubscribe_i18n();
  $$unsubscribe_user();
  $$unsubscribe_WEBUI_NAME();
  $$unsubscribe_config();
  return $$rendered;
});
const Page = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  return `${validate_component(Prompts, "Prompts").$$render($$result, {}, {}, {})}`;
});
export {
  Page as default
};
//# sourceMappingURL=_page.svelte.js.map
